nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Databufstart

Struct Databufstart 

#[repr(transparent)]
pub struct Databufstart(pub u32);
USB Data buffer start address

Tuple Fields

0: u32

Implementations

Source

impl Databufstart

pub const fn da_buf(&self) -> u16

Start address of the buffer pointer page where all endpoint data buffers are located.

pub const fn set_da_buf(&mut self, val: u16)

Start address of the buffer pointer page where all endpoint data buffers are located.