#[repr(transparent)]pub struct Inten(pub u32);Expand description
USB interrupt enable register
Tuple Fields
0: u32Implementations
Sourceimpl Inten
impl Inten
Sourcepub const fn ep_int_en(&self) -> u16
pub const fn ep_int_en(&self) -> u16
If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line indicated by the corresponding USB interrupt routing bit.
Sourcepub const fn set_ep_int_en(&mut self, val: u16)
pub const fn set_ep_int_en(&mut self, val: u16)
If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line indicated by the corresponding USB interrupt routing bit.
Sourcepub const fn frame_int_en(&self) -> bool
pub const fn frame_int_en(&self) -> bool
If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line indicated by the corresponding USB interrupt routing bit.
Sourcepub const fn set_frame_int_en(&mut self, val: bool)
pub const fn set_frame_int_en(&mut self, val: bool)
If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line indicated by the corresponding USB interrupt routing bit.
Sourcepub const fn dev_int_en(&self) -> bool
pub const fn dev_int_en(&self) -> bool
If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line indicated by the corresponding USB interrupt routing bit.
Sourcepub const fn set_dev_int_en(&mut self, val: bool)
pub const fn set_dev_int_en(&mut self, val: bool)
If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line indicated by the corresponding USB interrupt routing bit.